three_columns_landscape.pdf

## Metadata

Title | three_columns_landscape.pdf
Path | C:\Users\jenni\OneDrive\Documents\Code\burdoc\burdoc\tests\integration\data\inputs\three_columns_landscape.pdf
Pages | 0
PDF Metadata: format | PDF 1.7
PDF Metadata: title |
PDF Metadata: author | Joe Ennis
PDF Metadata: subject |
PDF Metadata: keywords |
PDF Metadata: creator | Microsoft® Word for Microsoft 365
PDF Metadata: producer | Microsoft® Word for Microsoft 365
PDF Metadata: creationDate | D:20230403055636+01'00'
PDF Metadata: modDate | D:20230403055636+01'00'
PDF Metadata: trapped |
PDF Metadata: encryption |

## Contents

1. Page 0
2. h2 :: Est Quis quasi aut iure esse.
3. h6 :: Cum soluta iste ad nulla omnis.

#### Page 0

No images

Path: | content.0.[0,0].bbox
Type: | addition

Key | Old | New
x1 |  | 249.65074157714844
y1 |  | 108.93826293945312
y0 |  | 74.61827850341797
x0 |  | 72.0

Path: | content.0.[1,1].bbox
Type: | addition

Key | Old | New
x1 |  | 279.2720031738281
y1 |  | 133.1385040283203
y0 |  | 124.06773376464844
x0 |  | 72.0

Path: | content.0.[2,2].bbox
Type: | addition

Key | Old | New
x1 |  | 282.5009460449219
y1 |  | 226.2885284423828
y0 |  | 134.57850646972656
x0 |  | 72.0

Path: | content.0.[3,3].bbox
Type: | addition

Key | Old | New
x1 |  | 283.465576171875
y1 |  | 285.91363525390625
y0 |  | 243.79360961914062
x0 |  | 72.0

Path: | content.0.[4,4].bbox
Type: | addition

Key | Old | New
x1 |  | 264.1490173339844
y1 |  | 321.5885314941406
y0 |  | 302.1977233886719
x0 |  | 72.0

Path: | content.0.[5,5].bbox
Type: | addition

Key | Old | New
x1 |  | 278.0369567871094
y1 |  | 394.0685119628906
y0 |  | 322.9085388183594
x0 |  | 72.0

Path: | content.0.[6,6].bbox
Type: | addition

Key | Old | New
x1 |  | 256.787841796875
y1 |  | 431.17059326171875
y0 |  | 409.6905517578125
x0 |  | 72.0

Path: | content.0.[7,7].bbox
Type: | addition

Key | Old | New
x1 |  | 282.2540588378906
y1 |  | 486.49853515625
y0 |  | 446.4185485839844
x0 |  | 72.0

Path: | content.0.[8,8].bbox
Type: | addition

Key | Old | New
x1 |  | 278.7080078125
y1 |  | 517.4545288085938
y0 |  | 487.74774169921875
x0 |  | 72.0

Path: | content.0.[9,9].bbox
Type: | addition

Key | Old | New
x1 |  | 523.9761962890625
y1 |  | 103.01850891113281
y0 |  | 73.37849426269531
x0 |  | 316.489990234375

Path: | content.0.[10,10].bbox
Type: | addition

Key | Old | New
x1 |  | 456.5320129394531
y1 |  | 127.42655181884766
y0 |  | 118.42655181884766
x0 |  | 316.489990234375

Path: | content.0.[11,11].bbox
Type: | addition

Key | Old | New
x1 |  | 527.6920166015625
y1 |  | 255.32850646972656
y0 |  | 142.73851013183594
x0 |  | 316.489990234375

Path: | content.0.[12,12].bbox
Type: | addition

Key | Old | New
x1 |  | 519.26513671875
y1 |  | 278.6396179199219
y0 |  | 270.599609375
x0 |  | 316.489990234375

Path: | content.0.[13,13].bbox
Type: | addition

Key | Old | New
x1 |  | 518.1071166992188
y1 |  | 334.6685485839844
y0 |  | 294.56854248046875
x0 |  | 316.489990234375

Path: | content.0.[14,14].bbox
Type: | addition

Key | Old | New
x1 |  | 527.1791381835938
y1 |  | 376.11651611328125
y0 |  | 335.9177551269531
x0 |  | 316.489990234375

Path: | content.0.[15,15].bbox
Type: | addition

Key | Old | New
x1 |  | 527.0771484375
y1 |  | 427.7885437011719
y0 |  | 377.3885192871094
x0 |  | 316.489990234375

Path: | content.0.[16,16].bbox
Type: | addition

Key | Old | New
x1 |  | 523.0223388671875
y1 |  | 462.5465393066406
y0 |  | 443.17852783203125
x0 |  | 316.489990234375

Path: | content.0.[17,17].bbox
Type: | addition

Key | Old | New
x1 |  | 520.6450805664062
y1 |  | 493.5785217285156
y0 |  | 463.81854248046875
x0 |  | 316.489990234375

Path: | content.0.[18,18].bbox
Type: | addition

Key | Old | New
x1 |  | 761.3414306640625
y1 |  | 92.7465591430664
y0 |  | 73.37849426269531
x0 |  | 560.8300170898438

Path: | content.0.[19,19].bbox
Type: | addition

Key | Old | New
x1 |  | 766.4442749023438
y1 |  | 113.50653839111328
y0 |  | 94.06653594970703
x0 |  | 560.8300170898438

Path: | content.0.[20,20].bbox
Type: | addition

Key | Old | New
x1 |  | 740.3894653320312
y1 |  | 134.09852600097656
y0 |  | 114.77851867675781
x0 |  | 560.8300170898438

Path: | content.0.[21,21].bbox
Type: | addition

Key | Old | New
x1 |  | 771.7905883789062
y1 |  | 210.20851135253906
y0 |  | 149.45851135253906
x0 |  | 560.8300170898438

Path: | content.0.[22,22].bbox
Type: | addition

Key | Old | New
x1 |  | 760.4293212890625
y1 |  | 230.96852111816406
y0 |  | 211.57774353027344
x0 |  | 560.8300170898438

Path: | content.0.[23,23].bbox
Type: | addition

Key | Old | New
x1 |  | 768.8025512695312
y1 |  | 275.9685363769531
y0 |  | 246.32850646972656
x0 |  | 560.8300170898438

Path: | content.0.[24,24].bbox
Type: | addition

Key | Old | New
x1 |  | 761.9921875
y1 |  | 296.7285461425781
y0 |  | 277.2177429199219
x0 |  | 560.8300170898438

Path: | content.0.[25,25].bbox
Type: | addition

Key | Old | New
x1 |  | 763.9122314453125
y1 |  | 331.42852783203125
y0 |  | 312.0377197265625
x0 |  | 560.8300170898438

Path: | content.0.[26,26].bbox
Type: | addition

Key | Old | New
x1 |  | 768.5521850585938
y1 |  | 352.11651611328125
y0 |  | 332.74853515625
x0 |  | 560.8300170898438

Path: | content.0.[27,27].bbox
Type: | addition

Key | Old | New
x1 |  | 758.3626098632812
y1 |  | 403.9085388183594
y0 |  | 353.5085144042969
x0 |  | 560.8300170898438

## Est Quis quasi aut iure esse.

Lorem ipsum dolor sit amet. Et quam illo Quo fugiat

eum sint voluptates? Qui suscipit voluptatemEa architecto ut molestiae expedita est galisum laborum qui Quis necessitatibus ut impedit reprehenderit aut molestiae accusamus. Quo quia voluptate sit saepe sequisit eligendi et omnis nostrum et impedit dolores. Eum voluptates aperiam id voluptas assumendaet necessitatibus id sequi neque. Et voluptatem maxime est voluptatem quosest illum non vero laudantium?

Vel delectus officia ut consequuntur similique ut suscipit vero.

Non voluptas dicta ut perspiciatis asperiores Ea dolore nam eaque praesentium. Aut ratione

ducimusIn voluptatibus quo autem iste quo enim facere est iste voluptas ea rerum assumenda sit repellat nihil. Ea dolor doloribus qui soluta iustoaut similique. Sit saepe rerum ut iusto maximeest dolor aut pariatur molestiae. Eos delectus corporisUt perferendis et consectetur praesentium qui quia vero in itaque Quis ut illum numquam.

Ea excepturi eveniet qui alias rerum id facere error.

Qui eligendi eaque ex enim commodiea neque! Est magnam voluptas est tempora temporibusnon provident sit quae alias non veritatis laudantium. Non nesciunt earum Non nulla eum impedit dolorum

et esse maxime aut libero voluptatem hic obcaecati optio a laboriosam sint. Aut cupiditate internos ea cumque praesentiumeum itaque qui sequi ipsa. Sit

debitis voluptas33 quos ea nobis galisum. Et facere debitisquo velit est tempora voluptate. Sed quaerat exercitationemet tempore est fugit quia?

###### Cum soluta iste ad nulla omnis.

Sed dolorum rerum sit adipisci fugiat Est obcaecati. Aut galisum architectoNon aperiam qui provident consequuntur qui nemo nihil in galisum dolore et fugiat explicabo! Aut neque amet qui nemo assumendaAut praesentium id voluptas ipsum qui illum ratione et molestiae laudantium 33 magni eligendi. Et internos consequatur ut voluptatibus culpa33 repellat quo voluptatem quam rem cupiditate maiores. Aut illo quisquam et officia voluptatemEt autem et minus perferendis nam laudantium facere ut fugit similique?

Et fugiat sapiente aut sapiente suscipit aut rerum rerum.

Sit odit aliquam et molestiae praesentiumrem ducimus cum soluta soluta. At tempora saepe ut architecto temporaaut voluptate. Ex saepe mollitia eos voluptatem consequatur Aut consequatur aut

debitis sunt et atque rerum qui quasi totam. Ut nobis minusEa earum qui quia vero est sint iste eum quam harum sed voluptate dicta. Ex enim quos At optio iure Sit facere ut ratione praesentium aut

pariatur reprehenderit. Quo debitis maiores ut quis ducimusAut internos aut suscipit sapiente a maxime dicta ea dolorem illum vel illo mollitia. Est velit incidunt in nostrum nobisAb quisquam est iure fugit id velit quia sit atque nobis id itaque sunt.

Lorem ipsum dolor sit amet. Ad quas atque et quod distinctio A fuga et voluptatum dolores aut nihil

delectus et modi maxime? Sed assumenda quas aut saepe quiaest rerum eum illum internos! Sed temporibus doloremeos officiis rem nihil esse.

Sit architecto veritatis vel odit repellatquo maiores aut accusantium unde. Est consequatur ipsam In

debitis quo nemo deleniti ut accusamus fuga in delectus perferendis. Aut tenetur deleniti ut

dolorem velitaut laborum. Est quis quaeratEt incidunt sit ipsam consequatur.

Sed Quis architectoEt laboriosam sed quas possimus est autem omnis qui quasi rerum et accusantium quaerat! Non eveniet quia sit fugiat ipsaQui perspiciatis vel inventore dolor et quae enim non eaque temporibus qui veritatis soluta. Sed sunt accusamus Et molestias id corrupti laboriosam aut

quos porro id nostrum quasi. Et quia molestiae sit laboriosam porroest dolores.

Aut distinctio omnis rem debitis fugitQuo deleniti et eligendi officiis aut maxime officia eos error fuga. Et dolores dolor Et dolorem quo sint doloribus et

suscipit officiis et aliquid rerum hic alias quasi non omnis omnis.

Ea provident ipsa Aut mollitia aut neque esse quo dolorem totam eos saepe nihil aut porro natus non

ratione voluptatem? Est pariatur nostrum Id sunt et nemo explicabo et exercitationem voluptas et

voluptatibus sapiente vel omnis veritatis id itaque animi. Vel soluta facereEst tempore ea veritatis impedit sit error minima et nihil omnis eum voluptatem facere. Et temporibus voluptateset ratione nam quod dicta.

## Est Quis quasi aut iure esse.

Lorem ipsum dolor sit amet. Et quam illo Quo fugiat

eum sint voluptates? Qui suscipit voluptatemEa architecto ut molestiae expedita est galisum laborum qui Quis necessitatibus ut impedit reprehenderit aut molestiae accusamus. Quo quia voluptate sit saepe sequisit eligendi et omnis nostrum et impedit dolores. Eum voluptates aperiam id voluptas assumendaet necessitatibus id sequi neque. Et voluptatem maxime est voluptatem quosest illum non vero laudantium?

Vel delectus officia ut consequuntur similique ut suscipit vero.

Non voluptas dicta ut perspiciatis asperiores Ea dolore nam eaque praesentium. Aut ratione

ducimusIn voluptatibus quo autem iste quo enim facere est iste voluptas ea rerum assumenda sit repellat nihil. Ea dolor doloribus qui soluta iustoaut similique. Sit saepe rerum ut iusto maximeest dolor aut pariatur molestiae. Eos delectus corporisUt perferendis et consectetur praesentium qui quia vero in itaque Quis ut illum numquam.

Ea excepturi eveniet qui alias rerum id facere error.

Qui eligendi eaque ex enim commodiea neque! Est magnam voluptas est tempora temporibusnon provident sit quae alias non veritatis laudantium. Non nesciunt earum Non nulla eum impedit dolorum

et esse maxime aut libero voluptatem hic obcaecati optio a laboriosam sint. Aut cupiditate internos ea cumque praesentiumeum itaque qui sequi ipsa. Sit

debitis voluptas33 quos ea nobis galisum. Et facere debitisquo velit est tempora voluptate. Sed quaerat exercitationemet tempore est fugit quia?

###### Cum soluta iste ad nulla omnis.

Sed dolorum rerum sit adipisci fugiat Est obcaecati. Aut galisum architectoNon aperiam qui provident consequuntur qui nemo nihil in galisum dolore et fugiat explicabo! Aut neque amet qui nemo assumendaAut praesentium id voluptas ipsum qui illum ratione et molestiae laudantium 33 magni eligendi. Et internos consequatur ut voluptatibus culpa33 repellat quo voluptatem quam rem cupiditate maiores. Aut illo quisquam et officia voluptatemEt autem et minus perferendis nam laudantium facere ut fugit similique?

Et fugiat sapiente aut sapiente suscipit aut rerum rerum.

Sit odit aliquam et molestiae praesentiumrem ducimus cum soluta soluta. At tempora saepe ut architecto temporaaut voluptate. Ex saepe mollitia eos voluptatem consequatur Aut consequatur aut

debitis sunt et atque rerum qui quasi totam. Ut nobis minusEa earum qui quia vero est sint iste eum quam harum sed voluptate dicta. Ex enim quos At optio iure Sit facere ut ratione praesentium aut

pariatur reprehenderit. Quo debitis maiores ut quis ducimusAut internos aut suscipit sapiente a maxime dicta ea dolorem illum vel illo mollitia. Est velit incidunt in nostrum nobisAb quisquam est iure fugit id velit quia sit atque nobis id itaque sunt.

Lorem ipsum dolor sit amet. Ad quas atque et quod distinctio A fuga et voluptatum dolores aut nihil

delectus et modi maxime? Sed assumenda quas aut saepe quiaest rerum eum illum internos! Sed temporibus doloremeos officiis rem nihil esse.

Sit architecto veritatis vel odit repellatquo maiores aut accusantium unde. Est consequatur ipsam In

debitis quo nemo deleniti ut accusamus fuga in delectus perferendis. Aut tenetur deleniti ut

dolorem velitaut laborum. Est quis quaeratEt incidunt sit ipsam consequatur.

Sed Quis architectoEt laboriosam sed quas possimus est autem omnis qui quasi rerum et accusantium quaerat! Non eveniet quia sit fugiat ipsaQui perspiciatis vel inventore dolor et quae enim non eaque temporibus qui veritatis soluta. Sed sunt accusamus Et molestias id corrupti laboriosam aut

quos porro id nostrum quasi. Et quia molestiae sit laboriosam porroest dolores.

Aut distinctio omnis rem debitis fugitQuo deleniti et eligendi officiis aut maxime officia eos error fuga. Et dolores dolor Et dolorem quo sint doloribus et

suscipit officiis et aliquid rerum hic alias quasi non omnis omnis.

Ea provident ipsa Aut mollitia aut neque esse quo dolorem totam eos saepe nihil aut porro natus non

ratione voluptatem? Est pariatur nostrum Id sunt et nemo explicabo et exercitationem voluptas et

voluptatibus sapiente vel omnis veritatis id itaque animi. Vel soluta facereEst tempore ea veritatis impedit sit error minima et nihil omnis eum voluptatem facere. Et temporibus voluptateset ratione nam quod dicta.

Parent File Contents